%* lsaf_endsession                                                                                       *;
%*                                                                                                       *;
%* Ends a session.                                                                                       *;
%*                                                                                                       *;
%* Syntax:                                                                                               *;
%* %LSAF_ENDSESSION(LSAF_SESSIONID=lsaf-sessionid);                                                      *;
%*                                                                                                       *;
%* @macvar _lsafRC_  The return code.                                                                    *;
%* @macvar _lsafMsg_ The return message.                                                                 *;
%*                                                                                                       *;
%* @param lsaf_sessionid - Required - The case-sensitive identifier of the session. This can be          *;
%*         retrieved by calling lsaf_getallsessions, lsaf_getusersessions, or lsaf_getmysessions.        *;
%*                                                                                                       *;
%* @macrotype LSAF                                                                                       *;
%* @since 2.3                                                                                            *;
%* @exposure external                                                                                    *;
%*                                                                                                       *;
%* @history 2019-12-02  initial code                                                                     *;

%macro lsaf_endsession(
  lsaf_sessionid=
  ) /des='End a session.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8
           message         length=$200
           logMsgPrefix    length=$70
           logMsgPrimary   length=$70
           logMsg          length=$300
           state           length=$20
           ;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/lsaf/macro/execution/session/SessionService");
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticStringMethod("endSession", "%bquote(&lsaf_sessionid)", results, state);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot end session: &lsaf_sessionid..";
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" The session: &lsaf_sessionid was ended.";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message;
    put logMsgPrefix " _lsafRC_= " returnCode;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_endsession;
