%* lsaf_getadminrepoutilization                                                                     *;
%*                                                                                                  *;
%* @macrotype LSAF                                                                                  *;
%* @since 2.5                                                                                       *;
%* @exposure external                                                                               *;
%*                                                                                                  *;
%* @history 2021-03-30  initial programming                                                         *;

%macro lsaf_getadminrepoutilization(
  lsaf_path=,
  lsaf_recursive=,
  sas_dsname=work.lsafgetadminrepoutilization
  ) /des='Gets the dashboard resource utilization information for child containers in the SAS Life Science Analytics Framework.';
  
  %if "&sas_dsname" EQ "" %then %let sas_dsname=work.lsafgetadminrepoutilization;

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);
  %let _lsafRowCount_=0;
  %let notesOption=%sysfunc(getoption(notes));
  
  options notes;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=type path name size);

    attrib returnCode       length=8
           message          length=$200
           logMsgPrefix     length=$70
           logMsgPrimary    length=$70
           logMsg           length=$300
           rowCount         length=8

           type             length=$32   label="Container Type"
           name             length=$32   label="Container Name"
           path             length=$2048 label="Full Path of the Container"
           size             length=8     label="Container Size" format=sizekmg.

    ;

    rowCount=0;
    
    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    
    declare javaobj srv("com/sas/lsaf/macro/content/utilization/ResourceUtilizationService") ;
    declare javaobj results("com/sas/lsaf/macro/content/utilization/SasResourceUtilizationResult");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("getAdminRepositoryUtilizationDetails", "%bquote(&lsaf_path)", "%bquote(&lsaf_recursive)", results) ;

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot retrieve repository resource utilization information." ;
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" Get repository resource utilization ran successfully." ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        results.callStringMethod("getTypeId", row, type);
        results.callStringMethod("getName", row, name);
        results.callStringMethod("getPath", row, path);
        results.callLongMethod("getResourceSize", row, size);
        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    if (rowCount=0) 
      then put logMsgPrefix " No repository resource utilizations were found.";
      else put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);
    call symputx("_lsafRowCount_", rowCount);

  run;
  
  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_lsafRowCount_ > 0) %then
  %do;
    options nonotes;
    proc sort data=&sas_dsname;
      by path;
    run;
  %end;

  options &notesOption;

%mend lsaf_getadminrepoutilization;
