%* lsaf_getextdictionaryid                                                                               *;                                                                                                                                                                                                                                       
%*                                                                                                       *;                                                                                                                                                                                                                                       
%* Gets the dictionary identifier for an external dictionary. The SAS macro variable                     *;
%* _lsafExtDictionaryId_ is set to the identifier. The dictionary name, status, and data type can be     *;
%* retrieved by calling the lsaf_getexternaldictionaries macro.                                          *;                                                                                                                                                                                                                                        
%*                                                                                                       *;                                                                                                                                                                                                                                       
%* Syntax:                                                                                               *;                                                                                                                                                                                                                                       
%* %LSAF_GETEXTDICTIONARYID(LSAF_DICTIONARY=lsaf-dictionary, LSAF_VERSION=lsaf-status,                   *;
%*                          LSAF_DATATYPE=lsaf-datatype);                                                *;     
%*                                                                                                       *;                                                                                                                                                                                                                                       
%* @macvar _lsafRC_  The return code.                                                                    *;                                                                                                                                                                                                                                       
%* @macvar _lsafMsg_ The return message.                                                                 *;                                                                                                                                                                                                                                       
%* @macvar _lsafExtDictionaryId_ The external dictionary identifier.                                     *;                                                                                                                                                                                                                                       
%*                                                                                                       *;                                                                                                                                                                                                                                       
%* @param lsaf_dictionary - Required - The case-sensitive name of the dictionary. This is the            *;
%*      dictionary variable in the lsafgetexternaldictionaries data set that is generated by the         *;
%*      lsaf_getexternaldictionaries macro.                                                              *;
%* @param lsaf_version - Required - The referenced version of the external dictionary.                   *;
%* @param lsaf_datatype - Required - The data type of the external dictionary.                           *;
%*      Valid values: TEXT, FLOAT, INTEGER.                                                              *;
%*                                                                                                       *;                                                                                                                                                                                                                                       
%* @macrotype LSAF                                                                                       *;                                                                                                                                                                                                                                       
%* @since 2.2                                                                                            *;                                                                                                                                                                                                                                       
%* @exposure external                                                                                    *;                                                                                                                                                                                                                                       
%*                                                                                                       *;                                                                                                                                                                                                                                       
%* @history 2019-07-23  Initial coding                                                                   *;
%* @history 2020-07-14  update for refactor of java service hierarchy.                                   *;
%*                                                                                                       *;                                                                                                                                                                                                                                       
                                                                                                                                                                                                                                                                                                                                     
%macro lsaf_getextdictionaryid(
  lsaf_dictionary=,
  lsaf_version=,
  lsaf_datatype=
  ) /des='Gets the dictionary ID for a SAS Life Science Analytics Framework external dictionary.';                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                     
  %****************************************;                                                                                                                                                                                                                                                                                         
  %* Initialize macro variables           *;                                                                                                                                                                                                                                                                                         
  %****************************************;                                                                                                                                                                                                                                                                                         
  %lsaf_getproductname();                                                                                                                                                                                                                                                                                                            
                                                                                                                                                                                                                                                                                                                                     
  %global _lsafMsg_
          _lsafRC_ 
          _lsafExtDictionaryId_
  ;                                                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                                                                                     
  %let _lsafRC_ =%str(-999);                                                                                                                                                                                                                                                                                                         
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);                                                                                                                                                                                                                                                
                                                                                                                                                                                                                                                                                                                                     
  %**********************************************;                                                                                                                                                                                                                                                                                   
  %* Start the datastep to call the java code   *;                                                                                                                                                                                                                                                                                   
  %**********************************************;                                                                                                                                                                                                                                                                                   
  data _null_;                                                                                                                                                                                                                                                                                                                       
    attrib returnCode      length=8;                                                                                                                                                                                                                                                                                                 
    attrib message         length=$200;                                                                                                                                                                                                                                                                                              
    attrib dictID          length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsgPrefix    length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsgPrimary   length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsg          length=$300;                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Declare the java objects        *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    declare javaobj srv("com/sas/lsaf/macro/clinical/externaldictionary/ExternalDictionaryService");                                                                                                                                                                                                                                                              
    declare javaobj results("com/sas/lsaf/macro/results/Result");                                                                                                                                                                                                                                                                     
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Attempt the operation           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    srv.callStaticStringMethod("getExternalDictionaryId", "%bquote(&lsaf_dictionary)", "%bquote(&lsaf_version)", "%bquote(&lsaf_datatype)", results, dictID);                          
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Retrieve the results            *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    results.callIntMethod("getReturnCode", returnCode);                                                                                                                                                                                                                                                                              
    results.callStringMethod("getReturnMessage", message);                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Process the results             *;                                                                                                                                                                                                                                                                                            
    %***********************************; 
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    logMsg=" The dictionary ID was returned for external dictionary: &lsaf_dictionary.." ;
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" The dictionary ID was not returned for external dictionary: &lsaf_dictionary..";
    end;
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Print messages in log           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    put;                                                                                                                                                                                                                                                                                                                             
    put logMsgPrimary " " logMsg;                                                                                                                                                                                                                                                                                                     
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafMsg_= " message;                                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafRC_= " returnCode;                                                                                                                                                                                                                                                                                       
    put logMsgPrefix " _lsafExtDictionaryId_= " dictID;                                                                                                                                                                                                                                                                                       
    put;                                                                                                                                                                                                                                                                                                                             
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Set the macro variables         *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    call symputx("_lsafRC_", returnCode);                                                                                                                                                                                                                                                                                            
    call symputx("_lsafMsg_", message);  
    call symputx("_lsafExtDictionaryId_", dictID);
                                                                                                                                                                                                                                                                                                                                     
  run;                                                                                                                                                                                                                                                                                                                               
                                                                                                                                                                                                                                                                                                                                     
%mend lsaf_getextdictionaryid;                                                                                                                                                                                                                                                                                                            