%* lsaf_getjobrunasowner                                                                          *;
%*                                                                                                *;
%* Gets the value of the property Run as owner for a repository job. The information is stored    *;
%* in the SAS macro variable _lsafJobRunAsOwner_.                                                 *;
%*                                                                                                *;
%* Syntax:                                                                                        *;
%* %LSAF_GETJOBRUNASOWNER(LSAF_PATH=lsaf-path);                                                   *;
%*                                                                                                *;
%* @macvar _lsafRC_  The return code.                                                             *;
%* @macvar _lsafMsg_ The return message.                                                          *;
%* @macvar _lsafJobRunAsOwner_ The value of the property.                                         *;
%*                                                                                                *;
%* @param lsaf_path - Required - The case-sensitive path of the job.                              *;
%*                                                                                                *;
%* @macrotype LSAF                                                                                *;
%* @since 2.3                                                                                     *;
%* @exposure external                                                                             *;
%*                                                                                                *;
%* @history 2020-03-18  initial coding.                                                           *;
%*                                                                                                *;

%macro lsaf_getjobrunasowner(
  lsaf_path=
  ) /des='Get the job run as owner property for a SAS Life Science Analytics Framework repository job.';
  
  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
          _lsafJobRunAsOwner_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %local _lsafRowCount_
         notesOption
  ;

  %let _lsafRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsgPrimary   length=$70;
    attrib logMsg          length=$300;
    attrib runasowner      length=$25;
  
    runasowner="";

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/lsaf/macro/execution/job/JobService") ;
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
     srv.callStaticStringMethod("getJobRunAsOwner", "%bquote(&lsaf_path)", results, runasowner);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot determine job run as owner property value for &lsaf_path.." ;
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" Returned job run as owner property value for &lsaf_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message;
    put logMsgPrefix " _lsafRC_= " returnCode;
    put logMsgPrefix " _lsafJobRunAsOwner_= " runasowner;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);
    call symputx("_lsafJobRunAsOwner_", kstrip(runasowner) ) ;
  run;
  
%mend lsaf_getjobrunasowner;
