%* lsaf_setjobrunasowner                                                                    *;                                                                                                                                                                                                                                       
%*                                                                                          *;                                                                                                                                                                                                                                       
%* Sets the job property Run as owner. Only the owner can change the property. Get the      *;
%* current value of the property by calling the %lsaf_getjobrunasowner macro.               *; 
%*                                                                                          *;                                                                                                                                                                                                                                       
%* Syntax:                                                                                  *;                                                                                                                                                                                                                                       
%* %LSAF_SETJOBRUNASOWNER(LSAF_PATH=lsaf-path, LSAF_runasowner=lsaf-runasowner);            *;
%*                                                                                          *;                                                                                                                                                                                                                                       
%* @macvar _lsafRC_  The return code.                                                       *;                                                                                                                                                                                                                                       
%* @macvar _lsafMsg_ The return message.                                                    *;                                                                                                                                                                                                                                       
%*                                                                                          *;                                                                                                                                                                                                                                       
%* @param lsaf_path - Required - The case-sensitive path of the job.                        *;
%* @param lsaf_runasowner - Required - The property value for property.                     *;
%*         Valid values: - 0: No, - 1: Yes.                                                 *;
%*                                                                                          *;                                                                                                                                                                                                                                       
%* @macrotype LSAF                                                                          *;                                                                                                                                                                                                                                       
%* @since 2.3                                                                               *;                                                                                                                                                                                                                                       
%* @exposure external                                                                       *;                                                                                                                                                                                                                                       
%*                                                                                          *;                                                                                                                                                                                                                                       
%* @history 2020-03-18  Initial coding                                                      *;
%*                                                                                          *;                                                                                                                                                                                                                                       
                                                                                                                                                                                                                                                                                                                                     
%macro lsaf_setjobrunasowner(
  lsaf_path=, 
  lsaf_runasowner=
  ) /des='Sets the job run as owner property value for a job.';                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                     
  %****************************************;                                                                                                                                                                                                                                                                                         
  %* Initialize macro variables           *;                                                                                                                                                                                                                                                                                         
  %****************************************;                                                                                                                                                                                                                                                                                         
  %lsaf_getproductname();                                                                                                                                                                                                                                                                                                            
                                                                                                                                                                                                                                                                                                                                     
  %global _lsafMsg_
          _lsafRC_                                                                                                                                                                                                                                                                                                                   
  ;                                                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                                                                                     
  %let _lsafRC_ =%str(-999);                                                                                                                                                                                                                                                                                                         
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);                                                                                                                                                                                                                                                
                                                                                                                                                                                                                                                                                                                                     
  %**********************************************;                                                                                                                                                                                                                                                                                   
  %* Start the datastep to call the java code   *;                                                                                                                                                                                                                                                                                   
  %**********************************************;                                                                                                                                                                                                                                                                                   
  data _null_;                                                                                                                                                                                                                                                                                                                       
    attrib returnCode      length=8;                                                                                                                                                                                                                                                                                                 
    attrib message         length=$200;                                                                                                                                                                                                                                                                                              
    attrib logMsgPrefix    length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsgPrimary   length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsg          length=$300;                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Declare the java objects        *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    declare javaobj srv("com/sas/lsaf/macro/execution/job/JobService");                                                                                                                                                                                                                                                              
    declare javaobj results("com/sas/lsaf/macro/results/Result");                                                                                                                                                                                                                                                                     
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Attempt the operation           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    srv.callStaticVoidMethod("setJobRunAsOwner", "%bquote(&lsaf_path)", "%bquote(&lsaf_runasowner)", results);                          
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Retrieve the results            *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    results.callIntMethod("getReturnCode", returnCode);                                                                                                                                                                                                                                                                              
    results.callStringMethod("getReturnMessage", message);                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Process the results             *;                                                                                                                                                                                                                                                                                            
    %***********************************; 
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Setting the run as owner property value was unsuccessful for &lsaf_path";
    end;
    else logMsg=" Setting the run as owner property value was successful for &lsaf_path";
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Print messages in log           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    put;                                                                                                                                                                                                                                                                                                                             
    put logMsgPrimary " " logMsg;                                                                                                                                                                                                                                                                                                     
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafMsg_= " message;                                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafRC_= " returnCode;                                                                                                                                                                                                                                                                                       
    put;                                                                                                                                                                                                                                                                                                                             
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Set the macro variables         *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    call symputx("_lsafRC_", returnCode);                                                                                                                                                                                                                                                                                            
    call symputx("_lsafMsg_", message);                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
  run;                                                                                                                                                                                                                                                                                                                               
                                                                                                                                                                                                                                                                                                                                     
%mend lsaf_setjobrunasowner;                                                                                                                                                                                                                                                                                                            
