%* lsaf_setstdycomponenteditstatus                                                                 *;                                                                                                                                                                                                                                       
%*                                                                                                 *;                                                                                                                                                                                                                                       
%* Sets the component edit status for a study.                                                     *;                                                                                                                                                                                                                                        
%*                                                                                                 *;                                                                                                                                                                                                                                       
%* Syntax:                                                                                         *;                                                                                                                                                                                                                                       
%* %LSAF_SETSTDYCOMPONENTEDITSTATUS(LSAF_STUDYID=lsaf-studyid,                                     *;
%*         LSAF_STUDYCOMPONENT=lsaf-studycomponent,                                                *;
%*         LSAF_EDITCOMPONENT=lsaf-editcomponent,                                                  *;
%*         LSAF_FORCECLAIM=lsaf-forceclaim);                                                       *;     
%*                                                                                                 *;                                                                                                                                                                                                                                       
%* @macvar _lsafRC_  The return code.                                                              *;                                                                                                                                                                                                                                       
%* @macvar _lsafMsg_ The return message.                                                           *;                                                                                                                                                                                                                                       
%*                                                                                                 *;                                                                                                                                                                                                                                       
%* @param lsaf_studyid - Required - The study item identifier. The identifier can be retrieved by  *;
%*          calling the lsaf_getstudyid macro.                                                     *;
%* @param lsaf_studycomponent - Required - The study component to set. Valid values: TABLES,       *;
%*          DICTIONARIES, SUPPORTING_DOCUMENTS, VALUE_LEVEL_METADATA, and TLFS.                    *;
%* @param lsaf_editcomponent - Optional - Indicates whether the component can be edited.           *;
%*          Valid values: 0 (Default)- Disallow, 1 - Allow.                                        *;
%* @param lsaf_forceclaim - Optional - Forces the operation even if the user does not own the      *;
%*          editability of the study component. Valid only if the user has the manage study        *;
%*          privilege.                                                                             *;
%*          Valid values: 0 (Default)- Do not force, 1 - Force.                                    *;
%*                                                                                                 *;                                                                                                                                                                                                                                       
%* @macrotype LSAF                                                                                 *;                                                                                                                                                                                                                                       
%* @since 2.2                                                                                      *;                                                                                                                                                                                                                                       
%* @exposure external                                                                              *;                                                                                                                                                                                                                                       
%*                                                                                                 *;                                                                                                                                                                                                                                       
%* @history 2019-07-16  Initial coding                                                             *;
%*                                                                                                 *;                                                                                                                                                                                                                                       
                                                                                                                                                                                                                                                                                                                                     
%macro lsaf_setstdycomponenteditstatus(
  lsaf_studyid=, 
  lsaf_studycomponent=,
  lsaf_editcomponent=0,
  lsaf_forceclaim=0
  ) /des='Sets edit status for a SAS Life Science Analytics Framework study component.';                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                     
  %****************************************;                                                                                                                                                                                                                                                                                         
  %* Initialize macro variables           *;                                                                                                                                                                                                                                                                                         
  %****************************************;                                                                                                                                                                                                                                                                                         
  %lsaf_getproductname();                                                                                                                                                                                                                                                                                                            
                                                                                                                                                                                                                                                                                                                                     
  %global _lsafMsg_
          _lsafRC_                                                                                                                                                                                                                                                                                                                   
  ;                                                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                                                                                     
  %let _lsafRC_ =%str(-999);                                                                                                                                                                                                                                                                                                         
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);                                                                                                                                                                                                                                                
                                                                                                                                                                                                                                                                                                                                     
  %**********************************************;                                                                                                                                                                                                                                                                                   
  %* Start the datastep to call the java code   *;                                                                                                                                                                                                                                                                                   
  %**********************************************;                                                                                                                                                                                                                                                                                   
  data _null_;                                                                                                                                                                                                                                                                                                                       
    attrib returnCode      length=8;                                                                                                                                                                                                                                                                                                 
    attrib message         length=$200;                                                                                                                                                                                                                                                                                              
    attrib logMsgPrefix    length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsgPrimary   length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsg          length=$300;                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Declare the java objects        *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    declare javaobj srv("com/sas/lsaf/macro/clinical/study/StudyService");                                                                                                                                                                                                                                                              
    declare javaobj results("com/sas/lsaf/macro/results/Result");                                                                                                                                                                                                                                                                     
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Attempt the operation           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    srv.callStaticVoidMethod("setStudyComponentEditStatus", "%bquote(&lsaf_studyid)", "%bquote(&lsaf_studycomponent)", "%bquote(&lsaf_editcomponent)", "%bquote(&lsaf_forceclaim)", results);                          
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Retrieve the results            *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    results.callIntMethod("getReturnCode", returnCode);                                                                                                                                                                                                                                                                              
    results.callStringMethod("getReturnMessage", message);                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Process the results             *;                                                                                                                                                                                                                                                                                            
    %***********************************; 
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    if &lsaf_editcomponent = 1 then
      logMsg=" The study component edit status was successfully set to ALLOW edits for component: &lsaf_studycomponent.." ;
    else if &lsaf_editcomponent = 0 then
      logMsg=" The study component edit status was successfully set to DISALLOW edits for component: &lsaf_studycomponent.." ;
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Setting the study component edit status was unsuccessful for &lsaf_studycomponent";
    end;
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Print messages in log           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    put;                                                                                                                                                                                                                                                                                                                             
    put logMsgPrimary " " logMsg;                                                                                                                                                                                                                                                                                                     
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafMsg_= " message;                                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafRC_= " returnCode;                                                                                                                                                                                                                                                                                       
    put;                                                                                                                                                                                                                                                                                                                             
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Set the macro variables         *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    call symputx("_lsafRC_", returnCode);                                                                                                                                                                                                                                                                                            
    call symputx("_lsafMsg_", message);                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
  run;                                                                                                                                                                                                                                                                                                                               
                                                                                                                                                                                                                                                                                                                                     
%mend lsaf_setstdycomponenteditstatus;                                                                                                                                                                                                                                                                                                            
