%* lsaf_updateversionlimits                                                                        *;
%*                                                                                                 *;
%* Sets the version limits on files and default version limits on containers.                      *;
%*                                                                                                 *;
%* The macro lsaf_getproperties returns the values for the minor and major version limits of       *;
%* an object.                                                                                      *;
%*                                                                                                 *;
%* Syntax:                                                                                         *;
%* %LSAF_UPDATEVERSIONLIMITS(LSAF_PATH=lsaf-path, <LSAF_VERSIONMAJOR=lsaf-versionmajor,            *;
%*       LSAF_VERSIONMINOR=lsaf-versionminor>);                                                    *;
%*                                                                                                 *;
%* @macvar _lsafRC_  The return code.                                                              *;
%* @macvar _lsafMsg_ The return message.                                                           *;
%*                                                                                                 *;
%* @param lsaf_path - Required - The case-sensitive path of the file or container item.            *;
%* @param lsaf_versionmajor - Optional - The major version limit. If not specified, the limit      *;
%*           is modified. If set to null, (such as lsaf_versionmajor=), the version limit is       *;
%*           to No Limit. Valid values are 1 through 10.                                           *;
%* @param lsaf_versionminor - Optional - The minor version limit. If not specified, the limit is   *;
%*           not modified. If set to null, (such as lsaf_versionminor=), the version limit is      *;
%*           to No Limit. Valid values are 1 through 10.                                           *;
%*                                                                                                 *;
%* @macrotype LSAF                                                                                 *;
%* @since 2.4                                                                                      *;
%* @exposure external                                                                              *;
%*                                                                                                 *;
%* @history 2020-09-04  initial coding                                                             *;
%*                                                                                                 *;
                                                                                                                                                                                                                                                                                                                                     
%macro lsaf_updateversionlimits(                                                                                                                                                                                                                                                                                                      
  lsaf_path=,                                                                                                                                                                                                                                                                                                                        
  lsaf_versionmajor=_LSAF_VALUE_NOT_PROVIDED_,                                                                                                                                                                                                                                                                                                                       
  lsaf_versionminor=_LSAF_VALUE_NOT_PROVIDED_                                                                                                                                                                                                                                                                                                          
  ) /des='Update the version limit of a file or set the default version of a container object.';                                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
  %****************************************;                                                                                                                                                                                                                                                                                         
  %* Initialize macro variables           *;                                                                                                                                                                                                                                                                                         
  %****************************************;                                                                                                                                                                                                                                                                                         
  %lsaf_getProductName();                                                                                                                                                                                                                                                                                                            
                                                                                                                                                                                                                                                                                                                                     
  %global _lsafMsg_                                                                                                                                                                                                                                                                                                                  
          _lsafRC_                                                                                                                                                                                                                                                                                                                   
  ;                                                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                                                                                     
  %let _lsafRC_=%str(-999);                                                                                                                                                                                                                                                                                                          
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);                                                                                                                                                                                                                                                
                                                                                                                                                                                                                                                                                                                                     
  %**********************************************;                                                                                                                                                                                                                                                                                   
  %* Start the datastep to call the java code   *;                                                                                                                                                                                                                                                                                   
  %**********************************************;                                                                                                                                                                                                                                                                                   
  data _null_;                                                                                                                                                                                                                                                                                                                       
    attrib returnCode      length=8;                                                                                                                                                                                                                                                                                                 
    attrib message         length=$200;                                                                                                                                                                                                                                                                                              
    attrib logMsgPrefix    length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsgPrimary   length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsg          length=$300;                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Declare the java objects        *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    declare javaobj srv("com/sas/lsaf/macro/content/repository/RepositoryService");                                                                                                                                                                                                                                                                 
    declare javaobj results("com/sas/lsaf/macro/results/Result");                                                                                                                                                                                                                                                                     
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Attempt the operation           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    srv.callStaticVoidMethod("updateVersionLimits", "%bquote(&lsaf_path)", "%bquote(&lsaf_versionmajor)", "%bquote(&lsaf_versionminor)", results);                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Retrieve the results            *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    results.callIntMethod("getReturnCode", returnCode);                                                                                                                                                                                                                                                                              
    results.callStringMethod("getReturnMessage", message);                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Process the results             *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    logMsg=" The version limits for the repository object &lsaf_path were updated." ;
    
    if (returnCode ne 0) then                                                                                                                                                                                                                                                                                                        
    do;                                                                                                                                                                                                                                                                                                                              
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";                                                                                                                                                                                                                                                                       
      logMsg=" Cannot update version limits for repository object &lsaf_path." ;                                                                                                                                                                                                                                                                                  
    end;                                                                                                                                                                                                                                                                                                                             
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Print messages in log           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    put;                                                                                                                                                                                                                                                                                                                             
    put logMsgPrimary " " logMsg;                                                                                                                                                                                                                                                                                                     
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafMsg_= " message ;                                                                                                                                                                                                                                                                                        
    put logMsgPrefix " _lsafRC_= " returnCode ;                                                                                                                                                                                                                                                                                      
    put;                                                                                                                                                                                                                                                                                                                             
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Set the macro variables         *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    call symputx("_lsafRC_", returnCode);                                                                                                                                                                                                                                                                                            
    call symputx("_lsafMsg_", message);                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
  run;                                                                                                                                                                                                                                                                                                                               
                                                                                                                                                                                                                                                                                                                                     
%mend lsaf_updateversionlimits;                                                                                                                                                                                                                                                                                                       
